@@ -76,10 +76,10 @@ class Seq2SeqTransformer(nn.Module):
             autoregressive = False
             if trg[0][0].item() != self.target_vocab.SOS_token: # Ensure there is an SOS token at the start of the trg, add if there isn't
                 trg = torch.cat((torch.full((1, batch_size), fill_value=self.target_vocab.SOS_token, dtype=torch.long, device=self.device), trg), dim=0)
-            if any(trg[-1, :] == self.target_vocab.EOS_token): # Ensure there is no EOS token in the target
-                # Make lists without EOS tokens
-                temp_trg = [row[(row != self.target_vocab.EOS_token)] for row in trg.transpose(0, 1)]
-                trg = torch.stack(temp_trg).transpose(0, 1)
+            # if any(trg[-1, :] == self.target_vocab.EOS_token): # Ensure there is no EOS token in the target
+            #     # Make lists without EOS tokens
+            #     temp_trg = [row[(row != self.target_vocab.EOS_token)] for row in trg.transpose(0, 1)]
+            #     trg = torch.stack(temp_trg).transpose(0, 1)
         
         # Embed src
         src_positions = torch.arange(0, src_len, device=self.device).unsqueeze(1).expand(src_len, batch_size)
